import logging
import os

from .e10_version import get_e10_version, NotAnE10Exception

log = logging.getLogger(__name__)

LED_OFF = 0
LED_RED = 1
LED_GREEN = 2
LED_YELLOW = 3

E10_1_0 = "1.0.0"
E10_1_1 = "1.1.0"

try:
    E10_VER = get_e10_version()
except NotAnE10Exception:
    E10_VER = None

log.debug("E10 Version for LED Control: %r", E10_VER)


def set_e10_led_off():
    if E10_VER == E10_1_0:
        os.system("echo 0 > /sys/class/leds/redled/brightness")
        os.system("echo 0 > /sys/class/leds/greenled/brightness")
    elif E10_VER == E10_1_1:
        os.system("/usr/bin/redled 0")
        os.system("/usr/bin/greenled 0")
    else:
        log.error("Attempted to set E10 Led on a Non-E10!")


def set_e10_led_red():
    if E10_VER == E10_1_0:
        os.system("echo 1 > /sys/class/leds/redled/brightness")
        os.system("echo 0 > /sys/class/leds/greenled/brightness")
    elif E10_VER == E10_1_1:
        os.system("/usr/bin/redled 1")
        os.system("/usr/bin/greenled 0")
    else:
        log.error("Attempted to set E10 Led on a Non-E10!")


def set_e10_led_green():
    if E10_VER == E10_1_0:
        os.system("echo 0 > /sys/class/leds/redled/brightness")
        os.system("echo 1 > /sys/class/leds/greenled/brightness")
    elif E10_VER == E10_1_1:
        os.system("/usr/bin/redled 0")
        os.system("/usr/bin/greenled 1")
    else:
        log.error("Attempted to set E10 Led on a Non-E10!")


def set_e10_led_yellow():
    if E10_VER == E10_1_0:
        os.system("echo 1 > /sys/class/leds/redled/brightness")
        os.system("echo 1 > /sys/class/leds/greenled/brightness")
    elif E10_VER == E10_1_1:
        os.system("/usr/bin/redled 1")
        os.system("/usr/bin/greenled 1")
    else:
        log.error("Attempted to set E10 Led on a Non-E10!")


def set_e10_led(state):
    if state == LED_OFF:
        set_e10_led_off()
    elif state == LED_RED:
        set_e10_led_red()
    elif state == LED_GREEN:
        set_e10_led_green()
    elif state == LED_YELLOW:
        set_e10_led_yellow()
    else:
        log.error("Invalid LED state: %r", state)
